from django.apps import AppConfig


class AllauthUiConfig(AppConfig):
    name = "allauth_ui"

    def ready(self):
        # pylint: disable=import-outside-toplevel
        from django.conf import settings

        settings.ALLAUTH_UI_THEME = getattr(settings, "ALLAUTH_UI_THEME", "light")



from django import template
from django.conf import settings
from slippers.templatetags.slippers import register_components

register = template.Library()


@register.simple_tag
def allauth_ui_theme():
    return settings.ALLAUTH_UI_THEME


register_components(
    {
        "container": "components/container.html",
        "form": "components/form.html",
    },
    register,
)
